{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2016-2020 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{% extends "invenio_communities/base.html" %}

{%- block javascript %}
  {{ super() }}
  {{ webpack['invenio-communities-members.js'] }}
{%- endblock javascript %}

{% set active_header_menu_item = 'members' %}

{%- block page_body %}
{% include "invenio_communities/header.html" %}

{%- set form_config = {"communityMember": community_member, "community": community} %}
<div
  id="app"
  data-form-config='{{ form_config | tojson }}'>
></div>
{%- endblock page_body %}
