{#
  Copyright (C) 2020 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
{% extends "invenio_communities/base.html" %}

{% set active_header_menu_item = active_menu_tab %}

{%- block page_body %}
  {% include "invenio_communities/details/header.html" %}
{%- endblock page_body %}
