.community-header {
  background: #F8F8F9;
  margin-bottom: 20px;
  margin-top: -20px;
  padding-top: 20px;

  &.ui.menu.secondary {
    margin-top: 0px;
    padding-top: 0px;
    .item.active {
      border-color: #fb8273;
    }
  }

  &.frontpage {
    // copied from SUI message class
    box-shadow: 0px 0px 0px 1px rgba(34, 36, 38, 0.22) inset;
  }

  .new-communities-frontpage {
    margin-right: -4px;
  }

  .type-label {
    margin-top: 15px;
  }

  .image.community-image {
    background-color: #E1E2E3;
    // Max dimensions based on default logo
    max-height: 112px;
    max-width: 104px;
    height: 112px;
    overflow: hidden;
  }

  .community-tags {
    margin-left: 5px;
  }

}

.underline {
  border-bottom: 1px solid;
}

.links-underline {
  text-decoration: underline;
}

.community-logo-form {
  margin-top: 10px;
  margin-left: 50px;
  max-width: 100%;
  max-height: 200px;
}

.title {
  text-align: center;
}

.communities-profile {
  .ck-editor__editable {
    min-height: 8.5em;
  }
  .communities-identifier {
    opacity: 0.5;
    pointer-events: None;
  }

  .header.communities-logo-header {
    margin-top: -1px;
    margin-bottom: 10px
  }

  .ui.negative.message.danger-zone {
    margin-top: 20px;
    margin-bottom: 10px;
    background-color: transparent;
    color: inherit;

    .header {
      color: inherit;
    }

    .column.margin-top-25 {
      margin-top: 25px;
    };

  }

  .divider.no-margin {
    margin: 0px;
  }

  .logo-buttons {
    & button:first-child {
      margin-top: -7px;
    }

    & button:not(:first-child) {
      margin-top: 7px;
    }
  }

}

.communities-creation {
  label.helptext{
    margin-top: -8px;
    margin-bottom: 15px;
    display: block;
    color: #737373;
    font-weight: normal;
    font-size: 0.9em;
  }

}

.communities-settings {
  &.grid {
    margin-bottom: 10px;
  }
  label.helptext{
    margin-top: -8px;
    margin-bottom: 15px;
    display: block;
    color: #737373;
    font-weight: normal;
    font-size: 0.9em;
  }
}

.communities-frontpage {

  .community-image {
    background-color: #E1E2E3;
    // Max dimensions based on default logo
    max-height: 173px;
    max-width: 209px;
    height: 173px;
    overflow: hidden;
  }
}
